@@ -331,7 +331,7 @@ Playlist::Playlist(PlaylistCollection *collection, const QString &name,
     m_collection(collection),
     m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
-    m_allowDuplicates(false),
+    m_allowDuplicates(true),
     m_applySharedSettings(true),
     m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
@@ -354,7 +354,7 @@ Playlist::Playlist(PlaylistCollection *collection, const PlaylistItemList &items
     m_collection(collection),
     m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
-    m_allowDuplicates(false),
+    m_allowDuplicates(true),
     m_applySharedSettings(true),
     m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
@@ -378,7 +378,7 @@ Playlist::Playlist(PlaylistCollection *collection, const QFileInfo &playlistFile
     m_collection(collection),
     m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
-    m_allowDuplicates(false),
+    m_allowDuplicates(true),
     m_applySharedSettings(true),
     m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
@@ -401,7 +401,7 @@ Playlist::Playlist(PlaylistCollection *collection, bool delaySetup, int extraCol
     m_collection(collection),
     m_fetcher(new WebImageFetcher(this)),
     m_selectedCount(0),
-    m_allowDuplicates(false),
+    m_allowDuplicates(true),
     m_applySharedSettings(true),
     m_columnWidthModeChanged(false),
     m_disableColumnWidthUpdates(true),
